"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RequestFactory = void 0;

var Helpers = _interopRequireWildcard(require("./helpers"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

class RequestFactory {
  static initialize(that) {
    that.requestID = 1;
    that.requestMap = {};
  }

  static getRequest(that, requestID) {
    return that.requestMap[requestID];
  }

  static newRequest(that, {
    timeout = 0
  }) {
    const requestID = that.requestID++;
    const promise = new Promise((resolve, reject) => {
      that.requestMap[requestID] = {
        resolve,
        reject
      };
    });
    return {
      requestID,
      promise: timeout ? Helpers.promiseWithTimeout(timeout, promise) : promise
    };
  }

  static resolveRequest(that, {
    requestID,
    success,
    params
  }) {
    try {
      const promise = that.requestMap[requestID];
      (success ? promise.resolve : promise.reject)(params);
    } catch (error) {
      console.log("RequestFactory, resolveRequest: failed");
      console.log(error);
    }

    ;
  }

  static resolveRequestFromObj(that, object) {
    try {
      const {
        requestID,
        success = false,
        ...other
      } = object;
      const promise = that.requestMap[requestID];
      (success ? promise.resolve : promise.reject)(other);
    } catch (error) {
      console.log("RequestFactory, resolveRequest: failed");
      console.log(error);
    }

    ;
  }

  static rejectRequest(that, {
    requestID,
    message = ""
  }) {
    const promise = that.requestMap[requestID];
    promise.reject(message);
  }

}

exports.RequestFactory = RequestFactory;
;
//# sourceMappingURL=RequestFactory.js.map