"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withModalLifecycle = withModalLifecycle;

var _react = _interopRequireDefault(require("react"));

var _ModalContext = require("../context/ModalContext");

var _Enums = require("../constants/Enums");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function withModalLifecycle(WrappedComponent) {
  var _class, _temp;

  return _temp = _class = class extends _react.default.PureComponent {
    constructor(...args) {
      super(...args);

      _defineProperty(this, "_handleChildRef", node => {
        const {
          ref
        } = this.props; // store a copy of the child comp ref

        this.childRef = node;

        if (typeof ref === 'function') {
          ref(node);
        } else if (ref) {
          ref.current = node;
        }

        ;
      });

      _defineProperty(this, "_handleOnModalBlur", event => {
        var _this$childRef, _this$childRef$onModa;

        (_this$childRef = this.childRef) === null || _this$childRef === void 0 ? void 0 : (_this$childRef$onModa = _this$childRef.onModalBlur) === null || _this$childRef$onModa === void 0 ? void 0 : _this$childRef$onModa.call(_this$childRef, event);
      });

      _defineProperty(this, "_handleOnModalFocus", event => {
        var _this$childRef2, _this$childRef2$onMod;

        (_this$childRef2 = this.childRef) === null || _this$childRef2 === void 0 ? void 0 : (_this$childRef2$onMod = _this$childRef2.onModalFocus) === null || _this$childRef2$onMod === void 0 ? void 0 : _this$childRef2$onMod.call(_this$childRef2);
      });

      _defineProperty(this, "_handleOnModalShow", event => {
        var _this$childRef3, _this$childRef3$onMod;

        (_this$childRef3 = this.childRef) === null || _this$childRef3 === void 0 ? void 0 : (_this$childRef3$onMod = _this$childRef3.onModalShow) === null || _this$childRef3$onMod === void 0 ? void 0 : _this$childRef3$onMod.call(_this$childRef3, event);
      });

      _defineProperty(this, "_handleOnModalDismiss", event => {
        var _this$childRef4, _this$childRef4$onMod;

        (_this$childRef4 = this.childRef) === null || _this$childRef4 === void 0 ? void 0 : (_this$childRef4$onMod = _this$childRef4.onModalDismiss) === null || _this$childRef4$onMod === void 0 ? void 0 : _this$childRef4$onMod.call(_this$childRef4, event);
      });

      _defineProperty(this, "_handleOnModalDidDismiss", event => {
        var _this$childRef5, _this$childRef5$onMod;

        (_this$childRef5 = this.childRef) === null || _this$childRef5 === void 0 ? void 0 : (_this$childRef5$onMod = _this$childRef5.onModalDidDismiss) === null || _this$childRef5$onMod === void 0 ? void 0 : _this$childRef5$onMod.call(_this$childRef5, event);
      });

      _defineProperty(this, "_handleOnModalWillDismiss", event => {
        var _this$childRef6, _this$childRef6$onMod;

        (_this$childRef6 = this.childRef) === null || _this$childRef6 === void 0 ? void 0 : (_this$childRef6$onMod = _this$childRef6.onModalWillDismiss) === null || _this$childRef6$onMod === void 0 ? void 0 : _this$childRef6$onMod.call(_this$childRef6, event);
      });

      _defineProperty(this, "_handleOnModalAttemptDismiss", event => {
        var _this$childRef7, _this$childRef7$onMod;

        (_this$childRef7 = this.childRef) === null || _this$childRef7 === void 0 ? void 0 : (_this$childRef7$onMod = _this$childRef7.onModalAttemptDismiss) === null || _this$childRef7$onMod === void 0 ? void 0 : _this$childRef7$onMod.call(_this$childRef7, event);
      });
    }

    componentDidMount() {
      const modalContext = this.context;
      const modalEmitter = modalContext.getEmitterRef();
      modalEmitter.addListener(_Enums.ModalEventKeys.onModalBlur, this._handleOnModalBlur);
      modalEmitter.addListener(_Enums.ModalEventKeys.onModalFocus, this._handleOnModalFocus);
      modalEmitter.addListener(_Enums.ModalEventKeys.onModalShow, this._handleOnModalShow);
      modalEmitter.addListener(_Enums.ModalEventKeys.onModalDismiss, this._handleOnModalDismiss);
      modalEmitter.addListener(_Enums.ModalEventKeys.onModalDidDismiss, this._handleOnModalDidDismiss);
      modalEmitter.addListener(_Enums.ModalEventKeys.onModalWillDismiss, this._handleOnModalWillDismiss);
      modalEmitter.addListener(_Enums.ModalEventKeys.onModalAttemptDismiss, this._handleOnModalAttemptDismiss);
    }

    componentWillUnmount() {
      const modalContext = this.context;
      const modalEmitter = modalContext.getEmitterRef();
      modalEmitter.removeListener(_Enums.ModalEventKeys.onModalBlur, this._handleOnModalBlur);
      modalEmitter.removeListener(_Enums.ModalEventKeys.onModalFocus, this._handleOnModalFocus);
      modalEmitter.removeListener(_Enums.ModalEventKeys.onModalShow, this._handleOnModalShow);
      modalEmitter.removeListener(_Enums.ModalEventKeys.onModalDismiss, this._handleOnModalDismiss);
      modalEmitter.removeListener(_Enums.ModalEventKeys.onModalDidDismiss, this._handleOnModalDidDismiss);
      modalEmitter.removeListener(_Enums.ModalEventKeys.onModalWillDismiss, this._handleOnModalWillDismiss);
      modalEmitter.removeListener(_Enums.ModalEventKeys.onModalAttemptDismiss, this._handleOnModalAttemptDismiss);
    }

    //#endregion
    render() {
      const props = this.props;
      return /*#__PURE__*/_react.default.createElement(WrappedComponent, _extends({}, props, {
        ref: this._handleChildRef
      }));
    }

  }, _defineProperty(_class, "contextType", _ModalContext.ModalContext), _temp;
}

;
//# sourceMappingURL=withModalLifecycle.js.map